USE audios;
CREATE TABLE Usuario(
	UserID INTEGER not null,
	nombre CHAR(50) not null UNIQUE,
    rol ENUM('administrador','evaluador','locutor') not null,
    password CHAR(32),
	PRIMARY KEY(UserID)
);

CREATE TABLE Lista(
    IDLista INTEGER not null,
    UserIDCreador INTEGER not null,
    password CHAR(20) not null,
    nombre_lista CHAR(200) not null,
    notas_evaluador VARCHAR(5000),
    notas_locutor VARCHAR(5000),
    fecha_creacion_lista DateTime,
    PRIMARY KEY(IDLista),
    FOREIGN KEY(UserIDCreador) references Usuario(UserID)
        ON DELETE CASCADE
        ON UPDATE CASCADE
);


CREATE TABLE Palabras(
	IDLista INTEGER not null,
    palabra CHAR(25) not null,
    texto_opcional VARCHAR(5000),
    texto_evaluador VARCHAR(5000),
    PRIMARY KEY(palabra,IDLista),
    FOREIGN KEY(IDLista) references Lista(IDLista)
        ON DELETE CASCADE
        ON UPDATE CASCADE
);

CREATE TABLE Metodos_evaluacion(
    palabra CHAR(25) not null,
    IDLista INTEGER not null,
    nombre_metodo CHAR(200) not null,
    metodo_evaluacion ENUM('rango','positivo_negativo') not null,
    rango_inferior INTEGER,
    rango_superior INTEGER,
    significado_inferior CHAR(200),
    significado_superior CHAR(200),
    primera_evaluacion_discreta CHAR(200),
    segunda_evaluacion_discreta CHAR(200),
    PRIMARY KEY(nombre_metodo,palabra,IDLista),
    FOREIGN KEY(palabra,IDLista) references Palabras(palabra,IDLista)
        ON DELETE CASCADE
        ON UPDATE CASCADE
);

CREATE TABLE Audios(
	UserIDlocutor INTEGER not null,
    palabra CHAR(25) not null,
    IDlista INTEGER not null,
    sessionID INTEGER not null,
    audio CHAR(250) not null,   
    fecha_creacion_sesion DateTime,
    PRIMARY KEY(palabra,IDlista,sessionID),
    FOREIGN KEY(palabra) references Palabras(palabra)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
    FOREIGN KEY(IDlista) references Lista(IDlista)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
    FOREIGN KEY(UserIDlocutor) references Usuario(UserID)
        ON DELETE CASCADE
        ON UPDATE CASCADE
);

CREATE TABLE Token(
    token VARCHAR(16) NOT NULL,
    UserID INTEGER not null,
    fecha_creacion_token DateTime,
    PRIMARY KEY(UserID),
    FOREIGN KEY(UserID) references Usuario(UserID)
        ON DELETE CASCADE
        ON UPDATE CASCADE
);

CREATE TABLE Evaluacion(
    UserIDEvaluador INTEGER not null,
    evaluacionID INTEGER not null,
    palabra CHAR(25) not null,
    IDlista INTEGER not null,
    sessionID INTEGER not null,
    nombre_metodo CHAR(200) not null,
    notas_evaluacion CHAR(200),
    evaluacion_rango INTEGER,
    evaluacion_discreta ENUM('bien','mal','nsnc'),
    fecha_creacion_evaluacion DateTime,
    PRIMARY KEY(evaluacionID, palabra, IDlista, sessionID, nombre_metodo),
    FOREIGN KEY(palabra, IDlista,sessionID) references Audios(palabra,IDlista,sessionID)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
    FOREIGN KEY(UserIDEvaluador) references Usuario(UserID)
        ON DELETE CASCADE
        ON UPDATE CASCADE,
    FOREIGN KEY(nombre_metodo) references Metodos_evaluacion(nombre_metodo)
        ON DELETE CASCADE
        ON UPDATE CASCADE
);

INSERT INTO Usuario(UserID, nombre, rol, password) VALUES (1,"administrador","administrador",MD5("pass"));
INSERT INTO Usuario(UserID, nombre, rol, password) VALUES (2,"locutor","locutor",NULL);
INSERT INTO Usuario(UserID, nombre, rol, password) VALUES (3,"evaluador","evaluador",NULL);



